#!/bin/bash -x
#SBATCH --account=deepacf
#SBATCH --nodes=1
#SBATCH --ntasks=48
##SBATCH --ntasks-per-node=1
#SBATCH --cpus-per-task=1
#SBATCH --output=preprocess_era5_to_crea6_data_tier2-out.%j
#SBATCH --error=preprocess_era5_to_crea6_data_tier2-err.%j
#SBATCH --time=24:00:00
#SBATCH --gres=gpu:0
#SBATCH --partition=mem192
##SBATCH --partition=batch
##SBATCH --partition=devel
#SBATCH --mail-type=ALL
#SBATCH --mail-user=XXX@fz-juelich.de
##jutil env activate -p cjjsc42

######### Template identifier (don't remove) #########
echo "Do not run the template scripts"
exit 99
######### Template identifier (don't remove) #########

# environmental variables to support cpus_per_task with Slurm>22.05
export OMP_NUM_THREADS=${SLURM_CPUS_PER_TASK}
export SRUN_CPUS_PER_TASK="${SLURM_CPUS_PER_TASK}"

# Name of virtual environment
VIRT_ENV_NAME="my_venv"

# Loading mouldes
source ../env_setup/modules.sh

# Activate virtual environment if needed (and possible)
if [ -z ${VIRTUAL_ENV} ]; then
   if [[ -f ../virtual_envs/${VIRT_ENV_NAME}/bin/activate ]]; then
      echo "Activating virtual environment..."
      source ../virtual_envs/${VIRT_ENV_NAME}/bin/activate
   else 
      echo "ERROR: Cannot find requested virtual environment ${VIRT_ENV_NAME}..."
      exit 1
   fi
fi

# Parameters 
src_dir_era5=/p/scratch/deepacf/maelstrom/maelstrom_data/ap5/downscaling_benchmark_dataset/rawdata/era5/
src_dir_crea6=/p/scratch/deepacf/maelstrom/maelstrom_data/ap5/downscaling_benchmark_dataset/rawdata/cosmo-rea6/     #  must be copied from /p/largedata/slmet/slmet111/met_data/dwd/cosmo-rea6/hourly/
const_file_era5=${src_dir_era5}/invariant/invariant.nc
const_file_crea6=${src_dir_crea6}/COSMO_REA6_CONST_withOUTsponge.nc
grid_des_tar=../grid_des/crea6_grid_tar_benchmark
out_dir=/p/scratch/deepacf/maelstrom/maelstrom_data/ap5/downscaling_benchmark_dataset/final_domain/
# selection of predictors and predictands
predictors='{"sf": ["t2m", "u10", "v10", "blh", "sshf", "slhf", "sp", "z", "lsm"], "ml": {"t": [137, 135, 131, 127, 122, 115]}}'
predictands='{"2D": {"t_2m": ""}, "const": {"hsurf": "", "FR_LAND": ""}}'

# time request
years=( 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 )
months="all"             # still hard-coded
# preprocessing method
method=ERA5_to_CREA6

srun --exclusive python -m mpi4py ../main_scripts/main_preprocessing.py \
  -in_datadir ${src_dir_era5} -tar_datadir ${src_dir_crea6} -out_dir ${out_dir} -grid_des_tar ${grid_des_tar} \
  -in_constfile ${const_file_era5} -tar_constfile ${const_file_crea6} -predictors "${predictors}" -predictands "${predictands}" \
  -y "${years[@]}" -method ${method}

