# Benchmarking with JUBE

### Introduction

In scope of deliverable 3.7 of the MAELSTROM project, this application was benchmarked on different hardwares at JSC and at E4.
Currently, benchmarking on the following machines is supported: A100 (on Juwels Booster and Jureca), V100 (on Juwels Cluster and HDF-ML), H100 (on Jureca), MI250x (on Jureca) and A2 (at E4) as well as GH200 (at E4).<br>
Benchmarking on IPU is not supported since the Keras extensions for IPU do not support overwriting the `train_step`-method.

### Running the benchmarks with JUBE

JUBE is made available via modules on JSC's and E4's HPC-cluster.
On JSC clusters, just run:
```
ml JUBE/2.6.1
```
On E4-clusters run:
``` 
module use /opt/share/users/testusr/modulefiles
module load jube
``` 
Afterwards, a benchmark run can be submitted as follows (examplary on JURECA):
``` 
jube run downscaling_benchmark.yaml -t a100_jrc
``` 
This will submit a series of 12 jobs on JURECA's A100-nodes. The jobs utilize a varying number of GPUs (1, 2 and 4) on a single node, and three experiments are executed for each GPU-configuration. <br>
The number of jobs varies with the hardware. For instance, the MI250x has eight (virtual) GPUs and thus, 15 jobs are submitted on 1, 2, 4 and GPUs, respectively. By contrast, GH200-ndes (on the E4-cluster) only have a single GPU/node which results into three submitted jobs only.
The supported sytems are related to JUBE's tags as follows:
- ```a100_jrc```: A100 on Jureca 
- ```a100_jwb```: A100 on Juwels Booster
- ```v100_jwc```: V100 on Juwels Cluster
- ```v100_hdfml```: V100 on HDF-ML
- ```mi250x_jrc```: MI250x on Jureca (requires container, see below)
- ```h100_jrc```: H100 on Jureca (requires container, see below)
- ```a2_e4```: A2 on E4's cluster 
- ```gh_e4```: GraceHopper 200 on E4's cluster (requires container, see below)
For testing purposes, the tag ```test``` should be add which will submit only one experiment (insetad of three) per GPU-configuration incl. a smaller number of epochs (two vs. four), e.g.
``` 
jube run downscaling_benchmark.yaml -t a100_jrc test
``` 

### Building of containers

Some systems, in particular the H100, the MI250x and the GH200, require a singularity container image to enable benchmarking. 
These container images must be provided in the ```containers```-directory and can be easily built with the ```makefile``` in this directory.
```
cd ../containers
make mi250.sif
```
will create the singluarity container for the MI250x-node on Jureca using the definition file ```mi250x.def```. <br>
The generation of the other singularity containers can be triggered in an analogous way, except for the H100-node.

### Experimenting on the H100-node

Since the last update of CUDA-driver around the 20th January, s strong performance degradation has been noted on the H100-nodes. 
While this issue is still under investigation, two singularity container versions are made available:
```
make h100_tf23.10.sif
make h100_tf23.04.sif
``` 
Where the former (latter) is based on Nvidia's provided Tensorflow image version 23.10 (23.04). 
The 23.10-version is deployed by default when running on the H100-node. To choose the 23.04-version, a corresponding tag has to be added to the ```jube```-command:
```
jube run downscaling_benchmark.yaml -t h100_jrc tf23.04
```
So far, better performance has been noted with ```keras.optimizers.legacy.Adam``` instead of the standard optimizer. However, this optimizer is not used by default and requires manual modification of the Python-script ```../models/wgan_model.py```. <br>
In particular, the l.159 (l.158) must be (un-)commented.
```
158            adam = keras.optimizers.legacy.Adam     # so far, better performance for H100-experiments
159            #adam = keras.optimizers.Adam           # default
```



